package be.iminds.ilabt.jfed.highlevel.tasks;

import be.iminds.ilabt.jfed.highlevel.controller.Task;
import be.iminds.ilabt.jfed.highlevel.controller.TaskExecution;
import be.iminds.ilabt.jfed.lowlevel.JFedException;
import be.iminds.ilabt.jfed.lowlevel.api_wrapper.UserAndSliceApiWrapper;
import be.iminds.ilabt.jfed.util.GeniUrn;
import be.iminds.ilabt.jfed.util.JavaFXLogger;

import javax.annotation.Nonnull;
import javax.annotation.Nullable;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

/**
 * User: twalcari
 * Date: 6/16/2015
 * Time: 17:54
 */
public class OtherUserSshKeysTask extends Task {
    //input parameters
    @Nonnull private final GeniUrn userUrn;
    @Nonnull private final List<Task> extraTaskDeps;

    //results
    @Nullable private List<String> keys;

    //environment parameters
    @Nonnull private final UserAndSliceApiWrapper userAndSliceApiWrapper;
    @Nonnull private final JavaFXLogger logger;
    @Nonnull private final HighLevelTaskFactory highLevelTaskFactory;

    public OtherUserSshKeysTask(@Nonnull GeniUrn userUrn,
                                @Nonnull List<Task> extraTaskDeps,
                                @Nonnull UserAndSliceApiWrapper userAndSliceApiWrapper,
                                @Nonnull JavaFXLogger logger,
                                @Nonnull HighLevelTaskFactory highLevelTaskFactory) {
        super("Get SSH keys for " + userUrn);
        this.userUrn = userUrn;
        this.extraTaskDeps = extraTaskDeps;
        this.userAndSliceApiWrapper = userAndSliceApiWrapper;
        this.logger = logger;
        this.highLevelTaskFactory = highLevelTaskFactory;
    }

    @Override
    public void doTask(@Nonnull TaskExecution taskExecution) throws JFedException, InterruptedException {
        keys = userAndSliceApiWrapper.getSshKeysForUser(JavaFXLogger.wrap(logger, taskExecution), userUrn);
    }

    @Nonnull public GeniUrn getUserUrn() {
        return userUrn;
    }

    @Nonnull public List<String> getKeys() {
        return keys == null ? Collections.emptyList() : keys;
    }

    @Nonnull
    @Override
    public List<Task> initDependsOn() {
        List<Task> res = new ArrayList<>();
        res.add(highLevelTaskFactory.getUserCredential());
        res.addAll(extraTaskDeps);
        return res;
    }
}
